#!/usr/bin/env python3

import argparse
from pathlib import Path

from .config import Context
from .mparse import create_markdown_parser
from .tree import SourceIndex, generate_list

# The command line parser
parser = argparse.ArgumentParser(prog='dragonglass')
parser.add_argument('source_dir', help='Source directory (Obsidian vault) for the conversion.')
parser.add_argument('dest_dir', help='Destination directory for the conversion.')
parser.add_argument('-C', '--config', help='Specifies an alternate name for the configuration file.')


def main() -> int:
    args = parser.parse_args()
    context = Context()

    context.source_dir = Path(args.source_dir).resolve()
    if not (context.source_dir.exists() and context.source_dir.is_dir()):
        print(f"{context.source_dir} is not a valid directory")
        return 1

    dest_dir = Path(args.dest_dir).resolve()
    if dest_dir.exists() and not dest_dir.is_dir():
        print(f"{dest_dir} exists but is not a valid directory")
        return 1

    context.load_config(args)

    nodes = generate_list(context.source_dir)
    for node in nodes:
        context.current_node = node
        node.load_metadata(context.source_dir)

    context.src_index = SourceIndex(nodes)

    mdparse = create_markdown_parser(context)
    for node in nodes:
        context.current_node = node
        node.parse_markdown(context.source_dir, mdparse)

    # TEMP
    for node in nodes:
        print(node)
        if node.metadata:
            print(f"Metadata: {node.metadata}")
        if node.text:
            print("----- BEGIN TEXT -----")
            print(node.text)
            print("------ END TEXT ------")

    return 0
